# Toad notes

This is notes.md in the root of the repository.
I'm using this file to keep track of what works in Toad and what doesn't.


## What works

- ACP support broadly works, barring a few rough edges.
  - Slash commands  
  - Tools calls
  - Modes (only reported by Claude so far)
  - Terminal
- Settings (press `F2` or `ctrl+,`).
- Multiline prompt (should be intuitive)
- Shell commands
- Colors in shell commands
- Interactive shell commands / terminals, a few rought edges but generally useful

## What doesn't work (yet)

- File tree doesn't do much
- Chat bots have been temporarily disabled
